function Y = echelle(X,mi,ma)
% X =  vecteur ou matrice
% mi = minimum du nouveau vecteur
% ma = maximum du nouveau vecteur
% output : vecteur mis a l echelle entre mi et ma

temp = X(:);
minX = min(temp);
maxX = max(temp);
Y = mi + (X - minX) .* (ma - mi) ./ (maxX - minX);